@@ -10,7 +10,7 @@ use overload '""' => "as_string";
 
 # ABSTRACT: Object and class methods for working with British postcodes.
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our @EXPORT_OK = qw/ pc_sort /;
 
@@ -88,7 +88,12 @@ sub strict {
 }
 
 
-    sub posttowns { Geo::UK::Postcode::Regex->posttowns( $_[0]->outcode ) }
+sub non_geographical {
+    $_[0]->components->{non_geographical} ? 1 : 0;
+}
+
+
+sub posttowns { Geo::UK::Postcode::Regex->posttowns( $_[0]->outcode ) }
 
 
 sub pc_sort($$) {
@@ -113,7 +118,7 @@ Geo::UK::Postcode - Object and class methods for working with British postcodes.
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -137,6 +142,9 @@ version 0.001
   $pc->valid;      # true if matches strict regex and has a valid outcode
   $pc->partial;    # true if postcode is for a district or sector only
 
+  $pc->non_geographical;    # true if outcode is known to be
+                            # non-geographical
+
   # Sort Postcode objects:
   use Geo::UK::Postcode qw/ pc_sort /;
   
@@ -219,6 +227,18 @@ or postcode sector (e.g. AB10 1).
 Returns true if postcode matches strict regex, meaning all characters are valid
 ( although postcode might not exist ) .
 
+=head2 non_geographical
+
+    if ($pc->non_geographical) {
+      ...
+    }
+
+Returns true if the outcode is known to be non-geographical. Note that
+geographical outcodes may have non-geographical postcodes within them.
+
+(Non-geographical postcodes are used for PO Boxes, or organisations
+receiving large amounts of post).
+
 =head2 posttowns
 
     my (@posttowns) = $postcode->posttowns;
@@ -237,15 +257,25 @@ Exportable sort function, sorts postcode objects
 
 =over
 
-=item Geo::Address::Mail::UK
+=item *
 
-=item Geo::Postcode
+L<Geo::Address::Mail::UK>
 
-=item Data::Validation::Constraints::Postcode
+=item *
 
-=item CGI::Untaint::uk_postcode
+L<Geo::Postcode>
 
-=item Form::Validator::UKPostcode 
+=item *
+
+L<Data::Validation::Constraints::Postcode>
+
+=item *
+
+L<CGI::Untaint::uk_postcode>
+
+=item *
+
+L<Form::Validator::UKPostcode>
 
 =back
 
@@ -261,6 +291,8 @@ Exportable sort function, sorts postcode objects
 
 =item Handle special case postcodes, like GIR 0AA and SAN TA1
 
+=item Find out which BX non-geographical districts are used.
+
 =back
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
